This is package that contains all modules needed to run
the database and other configurations
Contents:
    1. connecteod - connects to postgresql
    2.  workday - decides if a day is work day or not
    3. joblogmailsender - Send email once job is completed
    4. time2epoch2time - Changes time format to epoch and back
